@@ -19,25 +19,19 @@
 """Some tools for working with Gentoo.
 
 Avaible commands: 
- - ebuild_to_local package_atom
+ - ebuild_to_local CP
  
-   package_atom in the simple form dev-lang/python or similar. Complex atoms (or atoms with versions) aren't supported, yet. 
+   CP (cathegory/package) in the simple form dev-lang/python or similar. CPVs (cathegory/package-version) aren't supported, yet. 
    
- - ebuild_download_to_local package_atom download_url
+ - ebuild_download_to_local CP download_url
  
-   Download an ebuild to the local portage tree.    
+   Download an ebuild from bugs.gentoo.org to the local portage tree.    
 
 Source URL (Mercurial): U{http://freehg.org/u/ArneBab/babtools_gentoo/}
 
 PyPI URL: U{http://pypi.python.org/pypi/babtools_gentoo}
 """
 
-PORTAGE_DIR = "/usr/portage"
-PORTAGE_LOCAL = "/usr/local/portage"
-
-verbose = True
-
-
 # We need to be able to join paths and to check, if something's a dir or a file. 
 from os.path import join, isdir, isfile
 
@@ -47,15 +41,33 @@ from os import makedirs, listdir
 # And to copy files. 
 from shutil import copytree, copy
 
-def copy_ebuild_to_local_overlay(package_atom):  
+# Now we need the portage settings to get the overlays. 
+from portage import settings as portage_settings
+
+PORTAGE_DIR = portage_settings["PORTDIR"]
+# We just try the options for the local overlay. If it exists, we use it. 
+#: A list of possible locations of the overlay. At the moment: deprecated version and new (standardized for multiple overlays) version. 
+possible_local_overlays = ["/usr/local/portage", "/usr/portage/local/local-overlay"]
+for i in possible_local_overlays: 
+    if isdir(i) and i in portage_settings["PORTDIR_OVERLAY"]: 
+        local_overlay = i
+# If that worked, we can now assign it. 
+try: 
+    PORTAGE_LOCAL = local_overlay
+except: 
+    raise Exception("local overlay not found in " + str(possible_local_overlays))
+
+verbose = True
+
+def copy_ebuild_to_local_overlay(CP):  
     """Copy the ebuild dir to the local overlay.
     
     TODO implement cleanly, no hardcoded paths and such."""
     
     #: The system dir containing the ebuild
-    EBUILD_DIR = join(PORTAGE_DIR, package_atom)
+    EBUILD_DIR = join(PORTAGE_DIR, CP)
     #: The local dir containing the ebuild
-    EBUILD_DIR_LOCAL = join(PORTAGE_LOCAL, package_atom)
+    EBUILD_DIR_LOCAL = join(PORTAGE_LOCAL, CP)
     
     # If the dir of the ebuild exists
     if isdir(EBUILD_DIR): 
@@ -71,8 +83,8 @@ def copy_ebuild_to_local_overlay(package_atom):
         
         else: 
             # If the cathegory exists, only copy over the dir of the ebuild, 
-            if isdir(join(PORTAGE_LOCAL, package_atom.split("/")[0])): 
-                copytree(EBUILD_DIR, join(PORTAGE_LOCAL, package_atom.split("/")[0]))
+            if isdir(join(PORTAGE_LOCAL, CP.split("/")[0])): 
+                copytree(EBUILD_DIR, join(PORTAGE_LOCAL, CP.split("/")[0]))
             
                 if verbose: 
                     print "copied dir", EBUILD_DIR, "over to", EBUILD_DIR_LOCAL
@@ -80,9 +92,9 @@ def copy_ebuild_to_local_overlay(package_atom):
             # else create the cathegory first.     
             else: 
                 # Create the cathegory dir. 
-                makedirs(join(PORTAGE_LOCAL,join(PORTAGE_LOCAL, package_atom.split("/")[0])))
+                makedirs(join(PORTAGE_LOCAL,join(PORTAGE_LOCAL, CP.split("/")[0])))
                 if verbose: 
-                    print "created the cathegory dir", join(PORTAGE_LOCAL,join(PORTAGE_LOCAL, package_atom.split("/")[0]))
+                    print "created the cathegory dir", join(PORTAGE_LOCAL,join(PORTAGE_LOCAL, CP.split("/")[0]))
                 # And copy over the ebuild. 
                 copytree(EBUILD_DIR, EBUILD_DIR_LOCAL)
                 if verbose: 
@@ -93,11 +105,11 @@ def copy_ebuild_to_local_overlay(package_atom):
         raise Exception("package atom doesn't point to an existing ebuild dir.")
     
 
-def download_ebuild_to_local_overlay(package_atom, download_url):
-    """Download an ebuild from a given URL to the given package_atom in the local tree."""
+def download_ebuild_to_local_overlay(CP, download_url):
+    """Download an ebuild from a given URL to the given CP in the local tree."""
     
     #: The local dir containing the ebuild
-    EBUILD_DIR_LOCAL = join(PORTAGE_LOCAL, package_atom)
+    EBUILD_DIR_LOCAL = join(PORTAGE_LOCAL, CP)
     
     from urllib2 import urlopen
     
@@ -113,7 +125,7 @@ def download_ebuild_to_local_overlay(package_atom, download_url):
     filename = name_header.split(";")[1].strip()[6:-1]
     
     # Now make sure the local ebuild dir exists. 
-    create_local_ebuild_dir(package_atom)
+    create_local_ebuild_dir(CP)
     
     # And save the file there. 
     diskfile = open(join(EBUILD_DIR_LOCAL, filename), "w")
@@ -133,10 +145,10 @@ def download_ebuild_to_local_overlay(package_atom, download_url):
     # Done. 
     
 
-def create_local_ebuild_dir(package_atom):
+def create_local_ebuild_dir(CP):
     """Create the ebuild dir in the local portage tree, if it doesn't exist."""
     
-    EBUILD_DIR_LOCAL = join(PORTAGE_LOCAL, package_atom)
+    EBUILD_DIR_LOCAL = join(PORTAGE_LOCAL, CP)
     
     # If the local dir doesn't exists, create it. 
     if not isdir(EBUILD_DIR_LOCAL): 
@@ -154,11 +166,11 @@ def list_commands():
     """List avaible commands."""
     
     print "Avaible commands: "
-    print " - ebuild_to_local package_atom"
-    print "   package_atom in the simple form dev-lang/python or similar. Complex atoms (or atoms with versions) aren't supported, yet."
+    print " - ebuild_to_local CP"
+    print "   CP (cathegory/package) in the simple form dev-lang/python or similar. CPVs (cathegory/package-version) aren't supported, yet. "
     print ""
-    print " - ebuild_download_to_local package_atom download_url"
-    print "   Download an ebuild to the local portage tree. "
+    print " - ebuild_download_to_local CP download_url"
+    print "   Download an ebuild from bugs.gentoo.org to the local portage tree. "
 
 #### Self-Test ####
 
@@ -193,7 +205,7 @@ if __name__  == "__main__":
         if len(argv) < 4: 
             print_help()
         else: 
-            download_ebuild_to_local_overlay(package_atom=argv[2], download_url=argv[3])
+            download_ebuild_to_local_overlay(CP=argv[2], download_url=argv[3])
     else: 
         print "command not recognized:", argv[1]
         print_help()
